import { MailerModule } from "@nestjs-modules/mailer";
import { HandlebarsAdapter } from '@nestjs-modules/mailer/dist/adapters/handlebars.adapter';
import { Module } from "@nestjs/common";
import { ConfigModule } from "@nestjs/config";
import { JwtModule } from "@nestjs/jwt";
import { MongooseModule } from "@nestjs/mongoose";
import { AppController } from "./app.controller";
import { AppService } from "./app.service";
import JwtConfigService from "./core/jwt/jwt-config.service";
import { UsersSchema } from "./modules/CRUD/users/schema/users.schema";
import { UsersModule } from "./modules/CRUD/users/users.module";
import { SpacesModule } from "./modules/SpacesModule/spaces.module";
import { AuthModule } from "./modules/auth/auth.module";
import { MailSenderModule } from "./modules/mail-sender/mail-sender.module";
import { SiteFrontendModule } from "./modules/site-frontend/site-frontend.module";
import { AboutSectionOneCmsModule } from "./modules/CMS/about-section-one-cms/about-section-one-cms.module";
import { FaqSectionCmsModule } from "./modules/CMS/faq-section-cms/faq-section-cms.module";
import { TestimonialModule } from "./modules/CRUD/testimonial/testimonial.module";
import { LegalPageCmsModule } from "./modules/CMS/legal-page-cms/legal-page-cms.module";
import { HomePageHeroSectionCmsModule } from "./modules/CMS/home-page-hero-section/home-page-hero-cms.module";
import { CommonFormSectionCmsModule } from "./modules/CMS/common-form-section-cms/common-form-section-cms.module";
import { PrivacyPolicyPageCmsModule } from "./modules/CMS/privacy-policy-page-cms/privacy-policy-page-cms.module";
import { HomePageSectionTwoCmsModule } from "./modules/CMS/home-page-section-two-cms/home-page-section-two-cms.module";
import { CommonFormCmsModule } from "./modules/CMS/common-form-cms/common-form-cms.module";
import { SubmitFormSuccessCmsModule } from "./modules/CMS/submit-form-success-cms/submit-form-success-cms.module";
import { TermsConditionsPageCmsModule } from "./modules/CMS/terms-condition-page-cms/terms-condition-page-cms.module";
import { CommonVideoSectionCmsModule } from "./modules/CMS/common-video-section-cms/common-video-section-cms.module";
import { CategorySectionCmsModule } from "./modules/CMS/category-section-cms/category-section-cms.module";
import { NewsletterSectionCmsModule } from "./modules/CMS/newsletter-section-cms/newsletter-section-cms.module";
import { AttentionAlertCmsModule } from "./modules/CMS/attention-alert-cms/attention-alert-cms.module";
import { CategoryDetailsModule } from "./modules/CRUD/category-details/category-details.module";
import { BlogModule } from "./modules/CRUD/blog/blog.module";
import { VideoTestimonialCmsModule } from "./modules/CMS/video-testimonial-cms/video-testimonial-cms.module";
import { CtaOneSectionCmsModule } from "./modules/CMS/cta-one-section-cms/cta-one-section-cms.module";
import { VideoTestimonialModule } from "./modules/CRUD/video-testimonial/video-testimonial.module";
import { CtaTwoSectionCmsModule } from "./modules/CMS/cta-two-section-cms/cta-two-section-cms.module";
import { ContactPageCmsModule } from "./modules/CMS/contact-page-cms/contact-page-cms.module";
import { CtaThreeSectionCmsModule } from "./modules/CMS/cta-three-section-cms/cta-three-section-cms.module";
import { HeaderFooterCmsModule } from "./modules/CMS/header-footer-cms/header-footer-cms.module";
import { TestimonialSectionCmsModule } from "./modules/CMS/testimonial-section-cms/testimonial-section-cms.module";
import { BlogSectionCmsModule } from "./modules/CMS/blog-section-cms/blog-section-cms.module";
import { FaqModule } from "./modules/CRUD/faq/faq.module";
import { CommonFormSubmitModule } from "./modules/CRUD/common-form-submit/common-form-submit.module";
import { SocialLinksModule } from "./modules/CRUD/social-links/social-links.module";
import { ContactModule } from "./modules/CRUD/contact/contact.module";
import { NewsletterSubscriptionModule } from "./modules/CRUD/newsletter-subscription/newsletter-subscription.module";
import { PageTitleCmsModule } from "./modules/CMS/page-title-cms/page-title-cms.module";
import { PageBannerCmsModule } from "./modules/CMS/page-banner-cms/page-banner-cms.module";
import { HomePageComponentUIModule } from "./modules/ComponentUICMS/home-page-component-ui/home-page-component-ui.module";
import { AboutPageComponentUIModule } from "./modules/ComponentUICMS/about-page-component-ui/about-page-component-ui.module";
import { ContactPageComponentUIModule } from "./modules/ComponentUICMS/contact-page-component-ui/contact-page-component-ui.module";
import { BlogPageComponentUIModule } from "./modules/ComponentUICMS/blog-page-component-ui/blog-page-component-ui.module";
import { BlogDetailsPageComponentUIModule } from "./modules/ComponentUICMS/blog-details-page-component-ui/blog-details-page-component-ui.module";
import { PrivacyPolicyPageComponentUIModule } from "./modules/ComponentUICMS/privacy-policy-page-component-ui/privacy-policy-page-component-ui.module";
import { TermsAndConditionPageComponentUIModule } from "./modules/ComponentUICMS/terms-and-condition-page-component-ui/terms-and-condition-page-component-ui.module";
import { LegalPageComponentUIModule } from "./modules/ComponentUICMS/legal-page-component-ui/legal-page-component-ui.module";
import { TypesOfInjuriesPageComponentUIModule } from "./modules/ComponentUICMS/types-of-injuries-page-component-ui/types-of-injuries-page-component-ui.module";
import { FaqPageComponentUIModule } from "./modules/ComponentUICMS/faq-page-component-ui/faq-page-component-ui.module";
import { CommonComponentUIModule } from "./modules/ComponentUICMS/common-component-ui/common-component-ui.module";
import { SiteMapCmsModule } from "./modules/CMS/site-map-cms/site-map-cms.module";
import { RobotTextCmsModule } from "./modules/CMS/robot-text-cms/robot-text-cms.module";
import { MetaDataCmsModule } from "./modules/CMS/meta-data-cms/meta-data-cms.module";

@Module({
    imports: [
        ConfigModule.forRoot({
            isGlobal: true
        }),
        MongooseModule.forRoot(process.env.DATABASE_URL),
        MongooseModule.forFeature([
            { name: 'users', schema: UsersSchema }
        ]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MailerModule.forRoot({
            transport: {
                host: process.env.EMAIL_HOST,
                port: parseInt(process.env.EMAIL_PORT),
                secure: true,
                auth: {
                    user: process.env.EMAIL_USER,
                    pass: process.env.EMAIL_PASS
                }
            },
            defaults: {
                from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`
            },
            template: {
                dir: `${process.cwd()}`,
                adapter: new HandlebarsAdapter(),
                options: {
                    strict: true
                }
            }
        }),
        SpacesModule,
        UsersModule,
        AuthModule,
        MailSenderModule,
        SiteFrontendModule,
        AboutSectionOneCmsModule,
        HomePageHeroSectionCmsModule,
        HomePageSectionTwoCmsModule,
        CommonVideoSectionCmsModule,
        VideoTestimonialCmsModule,
        CtaOneSectionCmsModule,
        CtaTwoSectionCmsModule,
        CtaThreeSectionCmsModule,
        TestimonialSectionCmsModule,
        FaqSectionCmsModule,
        CommonFormSectionCmsModule,
        CommonFormCmsModule,
        SubmitFormSuccessCmsModule,
        CategorySectionCmsModule,
        CategoryDetailsModule,
        VideoTestimonialModule,
        BlogSectionCmsModule,
        NewsletterSectionCmsModule,
        AttentionAlertCmsModule,
        TestimonialModule,
        LegalPageCmsModule,
        PrivacyPolicyPageCmsModule,
        TermsConditionsPageCmsModule,
        BlogModule,
        ContactPageCmsModule,
        HeaderFooterCmsModule,
        CommonFormSubmitModule,
        SocialLinksModule,
        FaqModule,
        ContactModule,
        FaqModule,
        NewsletterSubscriptionModule,
        PageTitleCmsModule,
        PageBannerCmsModule,
        HomePageComponentUIModule,
        AboutPageComponentUIModule,
        ContactPageComponentUIModule,
        BlogPageComponentUIModule,
        BlogDetailsPageComponentUIModule,
        PrivacyPolicyPageComponentUIModule,
        TermsAndConditionPageComponentUIModule,
        LegalPageComponentUIModule,
        TypesOfInjuriesPageComponentUIModule,
        FaqPageComponentUIModule,
        CommonComponentUIModule,
        SiteMapCmsModule,
        RobotTextCmsModule,
        MetaDataCmsModule
    ],
    controllers: [AppController],
    providers: [AppService]
})
export class AppModule { }
