import mongoose, { Model, Types } from 'mongoose';
import { AttentionAlertCms } from './schema/attention-alert-cms.schema';
import { UpdateAttentionAlertCmsDto } from './dto/update-attention-alert-cms.dto';

export class AttentionAlertCmsRepository<AttentionAlertCmsDocument extends AttentionAlertCms> {
    constructor(private readonly model: Model<AttentionAlertCmsDocument>) { }

    async createEntity(data: UpdateAttentionAlertCmsDto): Promise<AttentionAlertCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<AttentionAlertCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateAttentionAlertCmsDto): Promise<AttentionAlertCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<AttentionAlertCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<AttentionAlertCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}