import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AttentionAlertCms } from "./schema/attention-alert-cms.schema";
import { UpdateAttentionAlertCmsDto } from "./dto/update-attention-alert-cms.dto";
import { AttentionAlertCmsRepository } from "./attention-alert-cms.repository";

@Injectable()
export class AttentionAlertCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('attention_alert_cms')
        private readonly attentionAlertCmsModel: Model<AttentionAlertCms>
    ) { }

    private readonly attentionAlertCmsRepository = new AttentionAlertCmsRepository(this.attentionAlertCmsModel);

    async updateOrCreateData(
        dto: UpdateAttentionAlertCmsDto,
    ): Promise<AttentionAlertCms | Error> {
        const isExists = await this.attentionAlertCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.attentionAlertCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.attentionAlertCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AttentionAlertCms[] | Error> {
        const data = await this.attentionAlertCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}