import mongoose, { Model, Types } from 'mongoose';
import { CategorySectionCms } from './schema/category-section-cms.schema';
import { UpdateCategorySectionCmsDto } from './dto/update-category-section-cms.dto';

export class CategorySectionCmsRepository<CategorySectionCmsDocument extends CategorySectionCms> {
    constructor(private readonly model: Model<CategorySectionCmsDocument>) { }

    async createEntity(data: UpdateCategorySectionCmsDto): Promise<CategorySectionCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CategorySectionCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCategorySectionCmsDto): Promise<CategorySectionCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CategorySectionCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CategorySectionCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}