import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CategorySectionCms } from "./schema/category-section-cms.schema";
import { CategorySectionCmsRepository } from "./category-section-cms.repository";
import { UpdateCategorySectionCmsDto } from "./dto/update-category-section-cms.dto";

@Injectable()
export class CategorySectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('category_section_cms')
        private readonly categorySectionCmsModel: Model<CategorySectionCms>
    ) { }

    private readonly categorySectionCmsRepository = new CategorySectionCmsRepository(this.categorySectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCategorySectionCmsDto
    ): Promise<CategorySectionCms | Error> {
        const isExists = await this.categorySectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.categorySectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.categorySectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CategorySectionCms[] | Error> {
        const data = await this.categorySectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}