import mongoose, { Model, Types } from 'mongoose';
import { CommonFormCms } from './schema/common-form-cms.schema';
import { UpdateCommonFormCmsDto } from './dto/update-common-form-cms.dto';

export class CommonFormCmsRepository<CommonFormCmsDocument extends CommonFormCms> {
    constructor(private readonly model: Model<CommonFormCmsDocument>) { }

    async createEntity(data: UpdateCommonFormCmsDto): Promise<CommonFormCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CommonFormCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCommonFormCmsDto): Promise<CommonFormCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CommonFormCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CommonFormCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}