import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CommonFormCms } from "./schema/common-form-cms.schema";
import { UpdateCommonFormCmsDto } from "./dto/update-common-form-cms.dto";
import { CommonFormCmsRepository } from "./common-form-cms.repository";

@Injectable()
export class CommonFormCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('common_form_cms')
        private readonly commonFormCmsModel: Model<CommonFormCms>
    ) { }

    private readonly commonFormCmsRepository = new CommonFormCmsRepository(this.commonFormCmsModel);

    async updateOrCreateData(
        dto: UpdateCommonFormCmsDto
    ): Promise<CommonFormCms | Error> {
        const isExists = await this.commonFormCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.commonFormCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.commonFormCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CommonFormCms[] | Error> {
        const data = await this.commonFormCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}