import mongoose, { Model, Types } from 'mongoose';
import { CommonFormSectionCms } from './schema/common-form-section-cms.schema';
import { UpdateCommonFormSectionCmsDto } from './dto/update-common-form-section-cms.dto';

export class CommonFormSectionCmsRepository<CommonFormSectionCmsDocument extends CommonFormSectionCms> {
    constructor(private readonly model: Model<CommonFormSectionCmsDocument>) { }

    async createEntity(data: UpdateCommonFormSectionCmsDto): Promise<CommonFormSectionCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CommonFormSectionCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCommonFormSectionCmsDto): Promise<CommonFormSectionCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CommonFormSectionCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CommonFormSectionCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}