import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CommonFormSectionCms } from "./schema/common-form-section-cms.schema";
import { CommonFormSectionCmsRepository } from "./common-form-section-cms.repository";
import { UpdateCommonFormSectionCmsDto } from "./dto/update-common-form-section-cms.dto";

@Injectable()
export class CommonFormSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('common_form_section_cms')
        private readonly commonFormSectionCmsModel: Model<CommonFormSectionCms>
    ) { }

    private readonly commonFormSectionCmsRepository = new CommonFormSectionCmsRepository(this.commonFormSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCommonFormSectionCmsDto
    ): Promise<CommonFormSectionCms | Error> {
        const isExists = await this.commonFormSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.commonFormSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.commonFormSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CommonFormSectionCms[] | Error> {
        const data = await this.commonFormSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}