import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { CommonVideoSectionCmsService } from "./common-video-section-cms.service";
import { UpdateCommonVideoSectionCmsDto } from "./dto/update-common-video-section-cms.dto";


@Controller({ path: "common-video-section-cms", version: Constants.API_VERSION_1 })

export class CommonVideoSectionCmsController {
    constructor(private readonly service: CommonVideoSectionCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "video", maxCount: 1 },
            { name: 'videoThumbnail', maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateCommonVideoSectionCmsDto,
        @UploadedFiles() files: {
            video?: UploadedMulterFileI,
            videoThumbnail?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
