import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CommonVideoSectionCms } from "./schema/common-video-section-cms.schema";
import { CommonVideoSectionCmsRepository } from "./common-video-section-cms.repository";
import { UpdateCommonVideoSectionCmsDto } from "./dto/update-common-video-section-cms.dto";




@Injectable()
export class CommonVideoSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('common_video_section_cms')
        private readonly commonVideoSectionCmsModel: Model<CommonVideoSectionCms>
    ) { }

    private readonly commonVideoSectionCmsRepository = new CommonVideoSectionCmsRepository(this.commonVideoSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCommonVideoSectionCmsDto,
        files: {
            video?: UploadedMulterFileI,
            videoThumbnail?: UploadedMulterFileI
        }
    ): Promise<CommonVideoSectionCms | Error> {
        if (files) {
            if (files && files.video) {
                const video: any = await this.doSpaceService.uploadFile(files.video[0], "common_video_section_cms/");
                dto.video = video;
            }
            if (files && files.videoThumbnail) {
                const videoThumbnail: any = await this.doSpaceService.uploadFile(files.videoThumbnail[0], "common_video_section_cms/");
                dto.videoThumbnail = videoThumbnail;
            }
        }
        const isExists = await this.commonVideoSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.commonVideoSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.commonVideoSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CommonVideoSectionCms[] | Error> {
        const data = await this.commonVideoSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}