import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { CtaOneSectionCmsService } from "./cta-one-section-cms.service";
import { UpdateCtaOneSectionCmsDto } from "./dto/update-cta-one-section-cms.dto";


@Controller({ path: "cta-one-section-cms", version: Constants.API_VERSION_1 })

export class CtaOneSectionCmsController {
    constructor(private readonly service: CtaOneSectionCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "backgroundImage", maxCount: 1 },
            { name: "featureImage", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateCtaOneSectionCmsDto,
        @UploadedFiles() files: {
            backgroundImage?: UploadedMulterFileI,
            featureImage?: UploadedMulterFileI,

        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
