import mongoose, { Model, Types } from 'mongoose';
import { CtaOneSectionCms } from './schema/cta-one-section-cms.schema';
import { UpdateCtaOneSectionCmsDto } from './dto/update-cta-one-section-cms.dto';




export class CtaOneSectionCmsRepository<CtaOneSectionCmsDocument extends CtaOneSectionCms> {
    constructor(private readonly model: Model<CtaOneSectionCmsDocument>) { }

    async createEntity(data: UpdateCtaOneSectionCmsDto): Promise<CtaOneSectionCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CtaOneSectionCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCtaOneSectionCmsDto): Promise<CtaOneSectionCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CtaOneSectionCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CtaOneSectionCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}