import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CtaOneSectionCmsRepository } from "./cta-one-section-cms.repository";
import { CtaOneSectionCms } from "./schema/cta-one-section-cms.schema";
import { UpdateCtaOneSectionCmsDto } from "./dto/update-cta-one-section-cms.dto";

@Injectable()
export class CtaOneSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('cta-one-section-cms')
        private readonly ctaOneSectionCmsModel: Model<CtaOneSectionCms>
    ) { }

    private readonly ctaOneSectionCmsRepository = new CtaOneSectionCmsRepository(this.ctaOneSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCtaOneSectionCmsDto,
        files: {
            backgroundImage?: UploadedMulterFileI,
            featureImage?: UploadedMulterFileI,
         
        }
    ): Promise<CtaOneSectionCms | Error> {
        if (files) {
            if (files && files.backgroundImage) {
                const backgroundImage: any = await this.doSpaceService.uploadFile(files.backgroundImage[0], "cta_one_section_cms/");
                dto.backgroundImage = backgroundImage;
            }
            if (files && files.featureImage) {
                const featureImage: any = await this.doSpaceService.uploadFile(files.featureImage[0], "cta_one_section_cms/");
                dto.featureImage = featureImage;
            }
         
        }
        const isExists = await this.ctaOneSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.ctaOneSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.ctaOneSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CtaOneSectionCms[] | Error> {
        const data = await this.ctaOneSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}