import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { CtaThreeSectionCmsService } from "./cta-three-section-cms.service";
import { UpdateCtaThreeSectionCmsDto } from "./dto/update-cta-three-section-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";


@Controller({ path: "cta-three-section-cms", version: Constants.API_VERSION_1 })

export class CtaThreeSectionCmsController {
    constructor(private readonly service: CtaThreeSectionCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "backgroundImage", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateCtaThreeSectionCmsDto,
        @UploadedFiles() files: {
            backgroundImage?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
