import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CtaThreeSectionCmsRepository } from "./cta-three-section-cms.repository";
import { CtaThreeSectionCms } from "./schema/cta-three-section-cms.schema";
import { UpdateCtaThreeSectionCmsDto } from "./dto/update-cta-three-section-cms.dto";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";




@Injectable()
export class CtaThreeSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('cta-three-section-cms')
        private readonly ctaThreeSectionCmsModel: Model<CtaThreeSectionCms>
    ) { }

    private readonly ctaThreeSectionCmsRepository = new CtaThreeSectionCmsRepository(this.ctaThreeSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCtaThreeSectionCmsDto,
        files: {
            backgroundImage?: UploadedMulterFileI
        }
    
    ): Promise<CtaThreeSectionCms | Error> {
        if (files) {
            if(files.backgroundImage) {
                const img: any = await this.doSpaceService.uploadFile(files.backgroundImage[0], "AboutSectionOneCms/");
                dto.backgroundImage = img;
            }
        }
        const isExists = await this.ctaThreeSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.ctaThreeSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.ctaThreeSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CtaThreeSectionCms[] | Error> {
        const data = await this.ctaThreeSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}