import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CtaTwoSectionCms } from "./schema/cta-two-section-cms.schema";
import { CtaTwoSectionCmsRepository } from "./cta-two-section-cms.repository";
import { UpdateCtaTwoSectionCmsDto } from "./dto/update-cta-two-section-cms.dto";



@Injectable()
export class CtaTwoSectionCmsService {
    constructor(
        @InjectModel('cta-two-section-cms')
        private readonly ctaTwoSectionCmsModel: Model<CtaTwoSectionCms>
    ) { }

    private readonly ctaTwoSectionCmsRepository = new CtaTwoSectionCmsRepository(this.ctaTwoSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateCtaTwoSectionCmsDto,
    
    ): Promise<CtaTwoSectionCms | Error> {
 
        const isExists = await this.ctaTwoSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.ctaTwoSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.ctaTwoSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CtaTwoSectionCms[] | Error> {
        const data = await this.ctaTwoSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}