import mongoose, { Model, Types } from 'mongoose';
import { FaqSectionCms } from './schema/faq-section-cms.schema';
import { UpdateFaqSectionCmsDto } from './dto/update-faq-section-cms.dto';

export class FaqSectionCmsRepository<FaqSectionCmsDocument extends FaqSectionCms> {
    constructor(private readonly model: Model<FaqSectionCmsDocument>) { }

    async createEntity(data: UpdateFaqSectionCmsDto): Promise<FaqSectionCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<FaqSectionCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateFaqSectionCmsDto): Promise<FaqSectionCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<FaqSectionCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<FaqSectionCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}