import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { FaqSectionCms } from "./schema/faq-section-cms.schema";
import { FaqSectionCmsRepository } from "./faq-section-cms.repository";
import { UpdateFaqSectionCmsDto } from "./dto/update-faq-section-cms.dto";

@Injectable()
export class FaqSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('faq_section_cms')
        private readonly faqSectionCmsModel: Model<FaqSectionCms>
    ) { }

    private readonly faqSectionCmsRepository = new FaqSectionCmsRepository(this.faqSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateFaqSectionCmsDto
    ): Promise<FaqSectionCms | Error> {
        const isExists = await this.faqSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.faqSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.faqSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<FaqSectionCms[] | Error> {
        const data = await this.faqSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}