import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateHeaderFooterCmsDto } from "./dto/update-header-footer-cms.dto";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { HeaderFooterCmsRepository } from "./header-footer-cms.repository";
import { HeaderFooterCms } from './schema/header-footer-cms.schema';

@Injectable()
export class HeaderFooterCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('header_footer_cms')
        private readonly aboutSectionOneCmsModel: Model<HeaderFooterCms>
    ) { }

    private readonly aboutSectionOneCmsRepository = new HeaderFooterCmsRepository(this.aboutSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdateHeaderFooterCmsDto,
        files: {
            logo?: UploadedMulterFileI
        }
    ): Promise<HeaderFooterCms | Error> {
        if (files) {
            if(files.logo) {
                const img: any = await this.doSpaceService.uploadFile(files.logo[0], "HeaderFooterCms/");
                dto.logo = img;
            }
        }
        const isExists = await this.aboutSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.aboutSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.aboutSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HeaderFooterCms[] | Error> {
        const data = await this.aboutSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}