import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateHomePageHeroCmsDto } from "./dto/update-home-page-hero-cms.dto";
import { HomePageHeroCmsService } from "./home-page-hero-cms.service";

@Controller({ path: "home-page-hero-section-cms", version: Constants.API_VERSION_1 })

export class HomePageHeroCmsController {
    constructor(private readonly service: HomePageHeroCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "ratingImage", maxCount: 1 },
            { name: "arrowImage", maxCount: 1 },
            { name: "backgroundImage", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHomePageHeroCmsDto,
        @UploadedFiles() files: {
            ratingImage?: UploadedMulterFileI,
            arrowImage?: UploadedMulterFileI,
            backgroundImage?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
