import mongoose, { Model, Types } from 'mongoose';
import {  HomePageHeroCms } from './schema/home-page-hero-cms.schema';
import { UpdateHomePageHeroCmsDto } from './dto/update-home-page-hero-cms.dto';

export class HomePageHeroCmsRepository<HomePageHeroCmsDocument extends HomePageHeroCms> {
    constructor(private readonly model: Model<HomePageHeroCmsDocument>) { }

    async createEntity(data: UpdateHomePageHeroCmsDto): Promise<HomePageHeroCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomePageHeroCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomePageHeroCmsDto): Promise<HomePageHeroCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<HomePageHeroCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomePageHeroCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}