import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

import { HomePageHeroCms } from "./schema/home-page-hero-cms.schema";
import { HomePageHeroCmsRepository } from "./home-page-hero-cms.repository";
import { UpdateHomePageHeroCmsDto } from "./dto/update-home-page-hero-cms.dto";


@Injectable()
export class HomePageHeroCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('home_page_hero_cms')
        private readonly homePageHeroCmsModel: Model<HomePageHeroCms>
    ) { }

    private readonly homePageHeroCmsRepository = new HomePageHeroCmsRepository(this.homePageHeroCmsModel);

    async updateOrCreateData(
        dto: UpdateHomePageHeroCmsDto,
        files: {
            ratingImage?: UploadedMulterFileI,
            arrowImage?: UploadedMulterFileI,
            backgroundImage?: UploadedMulterFileI,
        }
    ): Promise<HomePageHeroCms | Error> {
        if (files) {
            if (files && files.ratingImage) {
                const ratingImage: any = await this.doSpaceService.uploadFile(files.ratingImage[0], "home_page_hero_section_cms/");
                dto.ratingImage = ratingImage;
            }
            if (files && files.arrowImage) {
                const arrowImage: any = await this.doSpaceService.uploadFile(files.arrowImage[0], "home_page_hero_section_cms/");
                dto.arrowImage = arrowImage;
            }
            if (files && files.backgroundImage) {
                const backgroundImage: any = await this.doSpaceService.uploadFile(files.backgroundImage[0], "home_page_hero_section_cms/");
                dto.backgroundImage = backgroundImage;
            }
        }
        const isExists = await this.homePageHeroCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.homePageHeroCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.homePageHeroCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageHeroCms[] | Error> {
        const data = await this.homePageHeroCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}