import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import {  HomePageSectionTwoCmsService } from "./home-page-section-two-cms.service";
import { UpdateHomePageSectionTwoCmsDto } from "./dto/update-home-page-section-two-cms.dto";

@Controller({ path: "home-page-section-two-cms", version: Constants.API_VERSION_1 })

export class HomePageSectionTwoCmsController {
    constructor(private readonly service: HomePageSectionTwoCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "imageOne", maxCount: 1 },
            { name: "imageTwo", maxCount: 1 },
            { name: "imageThree", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHomePageSectionTwoCmsDto,
        @UploadedFiles() files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI,
            imageThree?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
