import mongoose, { Model, Types } from 'mongoose';
import { HomePageSectionTwoCms } from './schema/home-page-section-two-cms.schema';
import { UpdateHomePageSectionTwoCmsDto } from './dto/update-home-page-section-two-cms.dto';


export class HomePageSectionTwoCmsRepository<HomePageSectionTwoCmsDocument extends HomePageSectionTwoCms> {
    constructor(private readonly model: Model<HomePageSectionTwoCmsDocument>) { }

    async createEntity(data: UpdateHomePageSectionTwoCmsDto): Promise<HomePageSectionTwoCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomePageSectionTwoCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomePageSectionTwoCmsDto): Promise<HomePageSectionTwoCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<HomePageSectionTwoCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomePageSectionTwoCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}