import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { HomePageSectionTwoCms } from "./schema/home-page-section-two-cms.schema";
import { HomePageSectionTwoCmsRepository } from "./home-page-section-two-cms.repository";
import { UpdateHomePageSectionTwoCmsDto } from "./dto/update-home-page-section-two-cms.dto";



@Injectable()
export class HomePageSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('home_page_section_two_cms')
        private readonly homePageSectionTwoCmsModel: Model<HomePageSectionTwoCms>
    ) { }

    private readonly homePageSectionTwoCmsRepository = new HomePageSectionTwoCmsRepository(this.homePageSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateHomePageSectionTwoCmsDto,
        files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI,
            imageThree?: UploadedMulterFileI,
        }
    ): Promise<HomePageSectionTwoCms | Error> {
        if (files) {
            if (files && files.imageOne) {
                const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "home_page_section_two_cms/");
                dto.imageOne = imageOne;
            }
            if (files && files.imageTwo) {
                const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "home_page_section_two_cms/");
                dto.imageTwo = imageTwo;
            }
            if (files && files.imageThree) {
                const imageThree: any = await this.doSpaceService.uploadFile(files.imageThree[0], "home_page_section_two_cms/");
                dto.imageThree = imageThree;
            }
        }
        const isExists = await this.homePageSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.homePageSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.homePageSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageSectionTwoCms[] | Error> {
        const data = await this.homePageSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}