import mongoose, { Model, Types } from 'mongoose';
import { LegalPageCms } from './schema/legal-page-cms.schema';
import { UpdateLegalPageCmsDto } from './dto/update-legal-page-cms.dto';

export class LegalPageCmsRepository<LegalPageCmsDocument extends LegalPageCms> {
    constructor(private readonly model: Model<LegalPageCmsDocument>) { }

    async createEntity(data: UpdateLegalPageCmsDto): Promise<LegalPageCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<LegalPageCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateLegalPageCmsDto): Promise<LegalPageCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<LegalPageCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<LegalPageCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}