import mongoose, { Model, Types } from 'mongoose';
import { MetaDataCms } from './schema/meta-data-cms.schema';
import { UpdateMetaDataCmsDto } from './dto/update-meta-data-cms.dto';

export class MetaDataCmsRepository<MetaDataCmsDocument extends MetaDataCms> {
    constructor(private readonly model: Model<MetaDataCmsDocument>) { }

    async createEntity(data: UpdateMetaDataCmsDto): Promise<MetaDataCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<MetaDataCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateMetaDataCmsDto): Promise<MetaDataCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<MetaDataCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<MetaDataCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}