import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { MetaDataCmsRepository } from "./meta-data-cms.repository";
import { MetaDataCms } from "./schema/meta-data-cms.schema";
import { UpdateMetaDataCmsDto } from "./dto/update-meta-data-cms.dto";

@Injectable()
export class MetaDataCmsService {
    constructor(
        @InjectModel('meta_data_cms')
        private readonly MetaDataModel: Model<MetaDataCms>
    ) { }

    private readonly MetaDataCmsRepository = new MetaDataCmsRepository(this.MetaDataModel);

    async updateOrCreateData(
        dto: UpdateMetaDataCmsDto,
    
    ): Promise<MetaDataCms | Error> {
 
        const isExists = await this.MetaDataCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.MetaDataCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.MetaDataCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<MetaDataCms[] | Error> {
        const data = await this.MetaDataCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}