import mongoose, { Model, Types } from 'mongoose';
import { NewsletterSectionCms } from './schema/newsletter-section-cms.schema';
import { UpdateNewsletterSectionCmsDto } from './dto/update-newsletter-section-cms.dto';

export class NewsletterSectionCmsRepository<NewsletterSectionCmsDocument extends NewsletterSectionCms> {
    constructor(private readonly model: Model<NewsletterSectionCmsDocument>) { }

    async createEntity(data: UpdateNewsletterSectionCmsDto): Promise<NewsletterSectionCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<NewsletterSectionCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateNewsletterSectionCmsDto): Promise<NewsletterSectionCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<NewsletterSectionCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<NewsletterSectionCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}