import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { NewsletterSectionCms } from "./schema/newsletter-section-cms.schema";
import { UpdateNewsletterSectionCmsDto } from "./dto/update-newsletter-section-cms.dto";
import { NewsletterSectionCmsRepository } from "./newsletter-section-cms.repository";

@Injectable()
export class NewsletterSectionCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('newsletter_section_cms')
        private readonly newsletterSectionCmsModel: Model<NewsletterSectionCms>
    ) { }

    private readonly newsletterSectionCmsRepository = new NewsletterSectionCmsRepository(this.newsletterSectionCmsModel);

    async updateOrCreateData(
        dto: UpdateNewsletterSectionCmsDto
    ): Promise<NewsletterSectionCms | Error> {
        const isExists = await this.newsletterSectionCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.newsletterSectionCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.newsletterSectionCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<NewsletterSectionCms[] | Error> {
        const data = await this.newsletterSectionCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}