import mongoose, { Model, Types } from 'mongoose';
import { UpdatePageBannerCmsDto } from './dto/update-page-banner-cms.dto';
import { PageBannerCms } from './schema/page-banner-cms.schema';

export class PageBannerCmsRepository<PageBannerCmsDocument extends PageBannerCms> {
    constructor(private readonly model: Model<PageBannerCmsDocument>) { }

    async createEntity(data: UpdatePageBannerCmsDto): Promise<PageBannerCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<PageBannerCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdatePageBannerCmsDto): Promise<PageBannerCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<PageBannerCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<PageBannerCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}