import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdatePageBannerCmsDto } from "./dto/update-page-banner-cms.dto";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { PageBannerCmsRepository } from "./page-banner-cms.repository";
import { PageBannerCms } from './schema/page-banner-cms.schema';

@Injectable()
export class PageBannerCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('page_banner_cms')
        private readonly pageBannerCmsModel: Model<PageBannerCms>
    ) { }

    private readonly pageBannerCmsRepository = new PageBannerCmsRepository(this.pageBannerCmsModel);

    async updateOrCreateData(
        dto: UpdatePageBannerCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<PageBannerCms | Error> {
        if (files) {
            if(files.image) {
                const img: any = await this.doSpaceService.uploadFile(files.image[0], "PageBannerCms/");
                dto.image = img;
            }
        }
        const isExists = await this.pageBannerCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.pageBannerCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.pageBannerCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PageBannerCms[] | Error> {
        const data = await this.pageBannerCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}