import mongoose, { Model, Types } from 'mongoose';
import { PageTitleCms } from './schema/page-title-cms.schema';
import { UpdatePageTitleCmsDto } from './dto/update-page-title-cms.dto';

export class PageTitleCmsRepository<PageTitleCmsDocument extends PageTitleCms> {
    constructor(private readonly model: Model<PageTitleCmsDocument>) { }

    async createEntity(data: UpdatePageTitleCmsDto): Promise<PageTitleCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<PageTitleCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdatePageTitleCmsDto): Promise<PageTitleCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<PageTitleCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<PageTitleCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}