import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { PageTitleCmsRepository } from "./page-title-cms.repository";
import { PageTitleCms } from "./schema/page-title-cms.schema";
import { UpdatePageTitleCmsDto } from "./dto/update-page-title-cms.dto";

@Injectable()
export class PageTitleCmsService {
    constructor(
        @InjectModel('page_title_cms')
        private readonly pageTitleModel: Model<PageTitleCms>
    ) { }

    private readonly pageTitleCmsRepository = new PageTitleCmsRepository(this.pageTitleModel);

    async updateOrCreateData(
        dto: UpdatePageTitleCmsDto,
    
    ): Promise<PageTitleCms | Error> {
 
        const isExists = await this.pageTitleCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.pageTitleCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.pageTitleCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PageTitleCms[] | Error> {
        const data = await this.pageTitleCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}