import mongoose, { Model, Types } from 'mongoose';
import { RobotTextCms } from './schema/robot-text-cms.schema';
import { UpdateRobotTextCmsDto } from './dto/update-robot-text-cms.dto';

export class RobotTextCmsRepository<RobotTextCmsDocument extends RobotTextCms> {
    constructor(private readonly model: Model<RobotTextCmsDocument>) { }

    async createEntity(data: UpdateRobotTextCmsDto): Promise<RobotTextCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<RobotTextCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateRobotTextCmsDto): Promise<RobotTextCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<RobotTextCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<RobotTextCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}