import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { SiteMapCms } from "./schema/site-map-cms.schema";
import { SiteMapCmsRepository } from "./site-map-cms.repository";
import { UpdateSiteMapCmsDto } from "./dto/update-site-map-cms.dto";

@Injectable()
export class SiteMapCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('site_map_cms')
        private readonly model: Model<SiteMapCms>
    ) { }

    private readonly repository = new SiteMapCmsRepository(this.model);

    async updateOrCreateData(
        dto: UpdateSiteMapCmsDto
    ): Promise<SiteMapCms | Error> {
        const isExists = await this.repository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.repository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<SiteMapCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}