import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateSubmitFormSuccessCmsDto } from "./dto/update-submit-form-success-cms.dto";
import { SubmitFormSuccessCmsService } from "./submit-form-success-cms.service";

@Controller({ path: "submit-form-success-cms", version: Constants.API_VERSION_1 })

export class SubmitFormSuccessCmsController {
    constructor(private readonly service: SubmitFormSuccessCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateSubmitFormSuccessCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
