import mongoose, { Model, Types } from 'mongoose';
import { SubmitFormSuccessCms } from './schema/submit-form-success-cms.schema';
import { UpdateSubmitFormSuccessCmsDto } from './dto/update-submit-form-success-cms.dto';

export class SubmitFormSuccessCmsRepository<SubmitFormSuccessCmsDocument extends SubmitFormSuccessCms> {
    constructor(private readonly model: Model<SubmitFormSuccessCmsDocument>) { }

    async createEntity(data: UpdateSubmitFormSuccessCmsDto): Promise<SubmitFormSuccessCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<SubmitFormSuccessCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateSubmitFormSuccessCmsDto): Promise<SubmitFormSuccessCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<SubmitFormSuccessCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<SubmitFormSuccessCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}