import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { SubmitFormSuccessCms } from "./schema/submit-form-success-cms.schema";
import { UpdateSubmitFormSuccessCmsDto } from "./dto/update-submit-form-success-cms.dto";
import { SubmitFormSuccessCmsRepository } from "./submit-form-success-cms.repository";

@Injectable()
export class SubmitFormSuccessCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('submit_form_success_cms')
        private readonly submitFormSuccessCmsModel: Model<SubmitFormSuccessCms>
    ) { }

    private readonly submitFormSuccessCmsRepository = new SubmitFormSuccessCmsRepository(this.submitFormSuccessCmsModel);

    async updateOrCreateData(
        dto: UpdateSubmitFormSuccessCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<SubmitFormSuccessCms | Error> {
        if (files) {
            if(files.image) {
                const img: any = await this.doSpaceService.uploadFile(files.image[0], "SubmitFormSuccessCms/");
                dto.image = img;
            }
        }
        const isExists = await this.submitFormSuccessCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.submitFormSuccessCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.submitFormSuccessCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<SubmitFormSuccessCms[] | Error> {
        const data = await this.submitFormSuccessCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}