import mongoose, { Model, Types } from 'mongoose';
import { TermsConditionsPageCms } from './schema/terms-condition-page-cms.schema';
import { UpdateTermsConditionsPageCmsDto } from './dto/update-terms-condition-page-cms.dto';

export class TermsConditionsPageCmsRepository<TermsConditionsPageCmsDocument extends TermsConditionsPageCms> {
    constructor(private readonly model: Model<TermsConditionsPageCmsDocument>) { }

    async createEntity(data: UpdateTermsConditionsPageCmsDto): Promise<TermsConditionsPageCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<TermsConditionsPageCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateTermsConditionsPageCmsDto): Promise<TermsConditionsPageCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<TermsConditionsPageCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<TermsConditionsPageCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}