import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateVideoTestimonialCmsDto } from "./dto/update-video-testimonial-cms.dto";
import { VideoTestimonialCmsService } from "./video-testimonial-cms.service";



@Controller({ path: "video-testimonial-cms", version: Constants.API_VERSION_1 })

export class VideoTestimonialCmsController {
    constructor(private readonly service: VideoTestimonialCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "ratingImage", maxCount: 1 },
            { name: "googleImage", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateVideoTestimonialCmsDto,
        @UploadedFiles() files: {
            googleImage?: UploadedMulterFileI,

        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
