import mongoose, { Model, Types } from 'mongoose';
import { UpdateVideoTestimonialCmsDto } from './dto/update-video-testimonial-cms.dto';
import { VideoTestimonialCms } from './schema/video-testimonial-cms.schema';



export class VideoTestimonialCmsRepository<VideoTestimonialCmsDocument extends VideoTestimonialCms> {
    constructor(private readonly model: Model<VideoTestimonialCmsDocument>) { }

    async createEntity(data: UpdateVideoTestimonialCmsDto): Promise<VideoTestimonialCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<VideoTestimonialCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateVideoTestimonialCmsDto): Promise<VideoTestimonialCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<VideoTestimonialCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<VideoTestimonialCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}