import {
  BadRequestException,
  HttpException,
  HttpStatus,
  Injectable,
} from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';

import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { VideoTestimonialCms } from './schema/video-testimonial-cms.schema';
import { VideoTestimonialCmsRepository } from './video-testimonial-cms.repository';
import { UpdateVideoTestimonialCmsDto } from './dto/update-video-testimonial-cms.dto';

@Injectable()
export class VideoTestimonialCmsService {
  constructor(
    private readonly doSpaceService: DoSpacesService,
    @InjectModel('video_testimonial_cms')
    private readonly videoTestimonialCmsModel: Model<VideoTestimonialCms>,
  ) {}

  private readonly videoTestimonialCmsRepository =
    new VideoTestimonialCmsRepository(this.videoTestimonialCmsModel);

  async updateOrCreateData(
    dto: UpdateVideoTestimonialCmsDto,
    files: {
      ratingImage?: UploadedMulterFileI;
      googleImage?: UploadedMulterFileI;
    },
  ): Promise<VideoTestimonialCms | Error> {
    if (files) {
      if (files && files.ratingImage) {
        const ratingImage: any = await this.doSpaceService.uploadFile(
          files.ratingImage[0],
          'video_testimonial_cms/',
        );
        dto.ratingImage = ratingImage;
      }
      if (files && files.googleImage) {
        const googleImage: any = await this.doSpaceService.uploadFile(
          files.googleImage[0],
          'video_testimonial_cms/',
        );
        dto.googleImage = googleImage;
      }
    }
    const isExists =
      await this.videoTestimonialCmsRepository.findOneByFilterQuery({
        isDeleted: false,
      });
    if (!isExists) {
      const data = await this.videoTestimonialCmsRepository.createEntity(dto);
      if (!data) {
        throw new BadRequestException(`Failed to create data!`);
      }
      return ResponseUtils.successResponseHandler(
        201,
        'Data created successfully!',
        'data',
        data,
      );
    } else {
      const id = isExists?._id.toString();
      const data = await this.videoTestimonialCmsRepository.updateEntity(
        id,
        dto,
      );
      if (!data) {
        throw new BadRequestException(`Failed to update data!`);
      }
      return ResponseUtils.successResponseHandler(
        200,
        'Data updated successfully!',
        'data',
        data,
      );
    }
  }

  async findAll(): Promise<VideoTestimonialCms[] | Error> {
    const data = await this.videoTestimonialCmsRepository.findAll();
    if (!data) {
      throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND);
    }
    return ResponseUtils.successResponseHandler(
      200,
      'Data fetched successfully',
      'data',
      data,
    );
  }
}
