import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors,
} from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { CategoryDetailsService } from './category-details.service';
import { CreateCategoryDetailsDto } from './dto/create-category-details.dto';
import { UpdateCategoryDetailsDto } from './dto/update-category-details.dto';

@Controller({ path: 'category-details', version: Constants.API_VERSION_1 })
export class CategoryDetailsController {
    constructor(private readonly service: CategoryDetailsService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: 'image', maxCount: 1 }]))
    create(
        @Body() dto: CreateCategoryDetailsDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string,
    ) {
        return this.service.findAll(pageParam, limitParam);
    }

    @Get(':id')
    // @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: 'image', maxCount: 1 }]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateCategoryDetailsDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.delete(id);
    }
}
