import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { CategoryDetails } from './schema/category-details.schema';
import { CategoryDetailsRepository } from './category-details.repository';
import { CreateCategoryDetailsDto } from './dto/create-category-details.dto';
import { UpdateCategoryDetailsDto } from './dto/update-category-details.dto';
import { TypesOfInjuriesPageComponentUI } from 'src/modules/ComponentUICMS/types-of-injuries-page-component-ui/schema/types-of-injuries-page-component-ui.schema';
import { TypesOfInjuriesPageComponentUIRepository } from 'src/modules/ComponentUICMS/types-of-injuries-page-component-ui/types-of-injuries-page-component-ui.repository';
import { urlSlug } from 'src/utils/common-helper';



@Injectable()
export class CategoryDetailsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('category_details') private readonly model: Model<CategoryDetails>,

        @InjectModel('types_of_injuries_page_component_ui')
        private readonly TypesOfInjuriesPageComponentUIModel: Model<TypesOfInjuriesPageComponentUI>,
    ) { }

    private readonly repository = new CategoryDetailsRepository(this.model);
    private readonly TypesOfInjuriesPageComponentUIRepository = new TypesOfInjuriesPageComponentUIRepository(
        this.TypesOfInjuriesPageComponentUIModel,
    );
    async create(
        dto: CreateCategoryDetailsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<CategoryDetails> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "CategoryDetails/");
            dto.image = img;
        }

        dto.slug = urlSlug(dto.title)

        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to Category Details.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<CategoryDetails[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.repository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<CategoryDetails | null> {
        const data = await this.repository.findOneEntity(id);

        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        // const result = {
        //     data: data,
        //     typesOfInjuriesPageComponentUIData: TypesOfInjuriesPageComponentUIData[0],



        // };
        // return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", result);
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateCategoryDetailsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<CategoryDetails | null> {
        const res = await this.repository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        const foundImage = (res as CategoryDetails)?.image;
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "CategoryDetails/");
            dto.image = img;
        } else {
            dto.image = foundImage;
        }
        dto.slug = urlSlug(dto.title)
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.repository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }

        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}