import { BadRequestException, Injectable, NotFoundException } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CreateChangePasswordTokenDto } from "./dto/create-change-password-token.dto";
import { UpdateChangePasswordTokenDto } from "./dto/update-change-password-token.dto";
import { ChangePasswordToken } from "./schema/change-password-token.schema";
import { ChangePasswordTokenRepository } from "./change-password-token.repository";

@Injectable()
export class ChangePasswordTokenService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('change_password_token') private readonly changePasswordTokenModel: Model<ChangePasswordToken>) { }
    private readonly changePasswordTokenRepository = new ChangePasswordTokenRepository(this.changePasswordTokenModel);

    async create(dto: CreateChangePasswordTokenDto): Promise<ChangePasswordToken> {

        const data = await this.changePasswordTokenRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async findAll(pageParam: string, limitParam: string): Promise<ChangePasswordToken[]> {
        let data: any;
        if (pageParam && limitParam) {
            const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
            const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
            data = await this.changePasswordTokenRepository.paginate(page, limit);
        } else data = await this.changePasswordTokenRepository.findAll();

        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<ChangePasswordToken | null> {
        const data = await this.changePasswordTokenRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateChangePasswordTokenDto): Promise<ChangePasswordToken | null> {
        const res = await this.changePasswordTokenRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const data = await this.changePasswordTokenRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully.", "data", data);
    }
    async delete(id: string): Promise<void> {
        const res = await this.changePasswordTokenRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.changePasswordTokenRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}