import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { CommonFormSubmitService } from './common-form-submit.service';
import { CreateCommonFormSubmitDto } from './dto/create-common-form-submit.dto';
import { UpdateCommonFormSubmitDto } from './dto/update-common-form-submit.dto';


@Controller({ path: 'common-form-submit', version: Constants.API_VERSION_1 })
export class CommonFormSubmitController {
    constructor(private readonly service: CommonFormSubmitService) { }

    @Post()
    // @UseGuards(AdminAuthGuard)
    // @UseInterceptors(FileFieldsInterceptor([]))
    create(
        @Body() dto: CreateCommonFormSubmitDto,
    ) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string
    ) {
        return this.service.findAll(pageParam, limitParam);
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(
        @Param('id') id: string,
        @Body() dto: UpdateCommonFormSubmitDto
    ) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.delete(id);
    }
}
