import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { MongooseModule } from "@nestjs/mongoose";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { DoSpacesServicerovider } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UsersSchema } from "../users/schema/users.schema";
import { CommonFormSubmitSchema } from "./schema/common-form-submit.schema";
import { CommonFormSubmitController } from "./common-form-submit.controller";
import { CommonFormSubmitService } from "./common-form-submit.service";
import { ContactPageCmsSchema } from "src/modules/CMS/contact-page-cms/schema/contact-page-cms.schema";
import { MailSenderService } from "src/modules/mail-sender/mail-sender.service";


@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MongooseModule.forFeature([
            { name: 'users', schema: UsersSchema },
            { name: 'common-form-submit', schema: CommonFormSubmitSchema },
            { name: 'contact_page_cms', schema: ContactPageCmsSchema }
        ])
    ],
    controllers: [CommonFormSubmitController],
    providers: [CommonFormSubmitService, JwtHelper, DoSpacesService, DoSpacesServicerovider, MailSenderService]
})
export class CommonFormSubmitModule {}
