import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { SocialLinksService } from './social-links.service';
import { CreatSocialLinksDto } from './dto/create-social-links.dto';
import { UpdateSocialLinksDto } from './dto/update-social-links.dto';


@Controller({ path: 'social-links', version: Constants.API_VERSION_1 })
export class SocailLinksController {
    constructor(private readonly service: SocialLinksService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: 'image', maxCount: 1 }]))
    create(
        @Body() dto: CreatSocialLinksDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string
    ) {
        return this.service.findAll(pageParam, limitParam);
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([{ name: 'image', maxCount: 1 }]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateSocialLinksDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.delete(id);
    }
}
