import { BadRequestException, Injectable, NotFoundException } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CreateTemporaryPasswordDto } from "./dto/create-temporary-password.dto";
import { UpdateTemporaryPasswordDto } from "./dto/update-temporary-password.dto";
import { TemporaryPassword } from "./schema/temporary-password.schema";
import { TemporaryPasswordRepository } from "./temporary-password.repository";

@Injectable()
export class TemporaryPasswordService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('temporary_password') private readonly temporaryPasswordModel: Model<TemporaryPassword>) { }
    private readonly temporaryPasswordRepository = new TemporaryPasswordRepository(this.temporaryPasswordModel);

    async create(dto: CreateTemporaryPasswordDto): Promise<TemporaryPassword> {

        const data = await this.temporaryPasswordRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async findAll(pageParam: string, limitParam: string): Promise<TemporaryPassword[]> {
        let data: any;
        if (pageParam && limitParam) {
            const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
            const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
            data = await this.temporaryPasswordRepository.paginate(page, limit);
        } else data = await this.temporaryPasswordRepository.findAll();

        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<TemporaryPassword | null> {
        const data = await this.temporaryPasswordRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateTemporaryPasswordDto): Promise<TemporaryPassword | null> {
        const res = await this.temporaryPasswordRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const data = await this.temporaryPasswordRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully.", "data", data);
    }
    async delete(id: string): Promise<void> {
        const res = await this.temporaryPasswordRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.temporaryPasswordRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}