import mongoose, { Model, Types } from 'mongoose';
import { Testimonial } from './schema/testimonial.schema';
import { CreateTestimonialDto } from './dto/create-testimonial.dto';
import { UpdateTestimonialDto } from './dto/update-testimonial.dto';


export class TestimonialRepository<TestimonialDocument extends Testimonial> {
    constructor(private readonly model: Model<TestimonialDocument>) { }

    async createEntity(data: CreateTestimonialDto): Promise<Testimonial> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<Testimonial | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async findOneEntityBySlug(urlSlug: string): Promise<Testimonial | null> {
        try {
            return await this.model.findOne({ urlSlug: urlSlug, isDeleted: false });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, data: UpdateTestimonialDto): Promise<Testimonial | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({ ...query, isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.model
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 })

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<Testimonial[]> {
        return await this.model.find({ isDeleted: false });
    }
}