import { Body, Controller, Delete, Get, HttpCode, HttpStatus, Param, Patch, Post, Query, Req, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { Constants } from "src/utils/constants";
// import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import { UsersService } from "./users.service";
import { CreateUsersDto } from "./dto/create-users.dto";
import { UpdateUsersDto } from "./dto/update-users.dto";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AuthGuard } from "src/core/guards/auth.guard";

@Controller({ path: "users", version: Constants.API_VERSION_1 })

export class UsersController {
    constructor(private readonly service: UsersService) { }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    create(
        @Body() dto: CreateUsersDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.create(dto, files);
    }

    @Patch('/update-user-profile')
    @UseGuards(AuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: 'image', maxCount: 1 }
        ]
    ))
    updateUserProfile(
        @Req() request: any,
        @Body() dto: UpdateUsersDto,
        @UploadedFiles() files: { image: UploadedMulterFileI }
    ) {
        return this.service.update(request.user._id, dto, files);
    }

    @Post('/change-password')
    @HttpCode(HttpStatus.OK)
    @UseGuards(AuthGuard)
    async changePassword(@Body('currentPassword') currentPassword: string, @Body('newPassword') newPassword: string, @Req() request: any) {
        return await this.service.changePassword(currentPassword, newPassword, request.user._id);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(
        @Query('page') page?: string,
        @Query('limit') limit?: string,
        @Query('userType') userType?: string
    ) {
        return this.service.findAll(page, limit, userType);
    }

    @Get(":id")
    // @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    update(@Param("id") id: string,
        @Body() dto: UpdateUsersDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.delete(id);
    }
}
