import { Module } from "@nestjs/common";
import { UsersController } from "./users.controller";
import { UsersService } from "./users.service";
import { MongooseModule } from "@nestjs/mongoose";
import { UsersSchema } from "./schema/users.schema";
import JwtHelper from "src/core/jwt/jwt.helper";
import { JwtModule } from "@nestjs/jwt";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { DoSpacesServicerovider } from "src/modules/SpacesModule/SpacesService";
import { TemporaryPasswordSchema } from "../temporary-password/schema/temporary-password.schema";
import { MailSenderService } from "src/modules/mail-sender/mail-sender.service";

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MongooseModule.forFeature([
            { name: 'users', schema: UsersSchema },
            { name: "temporary_password", schema: TemporaryPasswordSchema }
        ])
    ],
    controllers: [UsersController],
    providers: [UsersService, JwtHelper, MailSenderService, DoSpacesService, DoSpacesServicerovider]
})
export class UsersModule { }
