import mongoose, { Model, Types } from 'mongoose';
import { VideoTestimonial } from './schema/video-testimonial.schema';
import { CreateVideoTestimonialDto } from './dto/create-video-testimonial.dto';
import { UpdateVideoTestimonialDto } from './dto/update-video-testimonial.dto';

export class VideoTestimonialRepository<VideoTestimonialDocument extends VideoTestimonial> {
    constructor(private readonly model: Model<VideoTestimonialDocument>) { }

    async createEntity(data: CreateVideoTestimonialDto): Promise<VideoTestimonial> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<VideoTestimonial | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async findOneEntityBySlug(urlSlug: string): Promise<VideoTestimonial | null> {
        try {
            return await this.model.findOne({ urlSlug: urlSlug, isDeleted: false });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, data: UpdateVideoTestimonialDto): Promise<VideoTestimonial | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({ ...query, isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.model
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 })

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<VideoTestimonial[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<VideoTestimonial | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.model.countDocuments({
                isDeleted: false
            });
        } catch (e) {
            return e;
        }
    }
}