import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { VideoTestimonial } from './schema/video-testimonial.schema';
import { VideoTestimonialRepository } from './video-testimonial.repository';
import { CreateVideoTestimonialDto } from './dto/create-video-testimonial.dto';
import { UpdateVideoTestimonialDto } from './dto/update-video-testimonial.dto';

@Injectable()
export class VideoTestimonialService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('video_testimonial') private readonly model: Model<VideoTestimonial>
    ) { }

    private readonly repository = new VideoTestimonialRepository(this.model);

    async create(
        dto: CreateVideoTestimonialDto,
        files: {
            video?: UploadedMulterFileI,
            videoThumbnail?: UploadedMulterFileI,
            userImage?: UploadedMulterFileI,
            platformIcon?: UploadedMulterFileI,
        }
    ): Promise<VideoTestimonial> {
        if (files) {
            if (files && files.video) {
                const video: any = await this.doSpaceService.uploadFile(files.video[0], "video_testimonial/");
                dto.video = video;
            }
            if (files && files.videoThumbnail) {
                const videoThumbnail: any = await this.doSpaceService.uploadFile(files.videoThumbnail[0], "video_testimonial/");
                dto.videoThumbnail = videoThumbnail;
            }
            if (files && files.userImage) {
                const userImage: any = await this.doSpaceService.uploadFile(files.userImage[0], "video_testimonial/");
                dto.userImage = userImage;
            }
            if (files && files.platformIcon) {
                const platformIcon: any = await this.doSpaceService.uploadFile(files.platformIcon[0], "video_testimonial/");
                dto.platformIcon = platformIcon;
            }
        }

        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to VideoTestimonial.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<VideoTestimonial[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.repository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<VideoTestimonial | null> {
        const data = await this.repository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOneByFilterQuery(query: any): Promise<VideoTestimonial | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }

    async update(
        id: string, 
        dto: UpdateVideoTestimonialDto,
        files: {
            video?: UploadedMulterFileI,
            videoThumbnail?: UploadedMulterFileI,
            userImage?: UploadedMulterFileI,
            platformIcon?: UploadedMulterFileI,
        }
    ): Promise<VideoTestimonial | null> {
        const res = await this.repository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        const foundVideo = (res as VideoTestimonial)?.video;
        if (files && files.video) {
            const video: any = await this.doSpaceService.uploadFile(files.video[0], "video-testimonial/");
            dto.video = video;
        } else {
            dto.video = foundVideo;
        }

        const foundVideoThumbnail = (res as VideoTestimonial)?.videoThumbnail;
        if (files && files.videoThumbnail) {
            const videoThumbnail: any = await this.doSpaceService.uploadFile(files.videoThumbnail[0], "video-testimonial/");
            dto.videoThumbnail = videoThumbnail;
        } else {
            dto.videoThumbnail = foundVideoThumbnail;
        }

        const foundUserImage = (res as VideoTestimonial)?.userImage;
        if (files && files.userImage) {
            const userImage: any = await this.doSpaceService.uploadFile(files.userImage[0], "video-testimonial/");
            dto.userImage = userImage;
        } else {
            dto.userImage = foundUserImage;
        }

        const foundPlatformIcon = (res as VideoTestimonial)?.platformIcon;
        if (files && files.platformIcon) {
            const platformIcon: any = await this.doSpaceService.uploadFile(files.platformIcon[0], "video-testimonial/");
            dto.platformIcon = platformIcon;
        } else {
            dto.platformIcon = foundPlatformIcon;
        }

        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.repository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }

        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}