import mongoose, { Model, Types } from 'mongoose';
import { AboutPageComponentUI } from './schema/about-page-component-ui.schema';
import { UpdateAboutPageComponentUIDto } from './dto/update-about-page-component-ui.dto';


export class AboutPageComponentUIRepository<AboutPageComponentUIDocument extends AboutPageComponentUI> {
    constructor(private readonly model: Model<AboutPageComponentUIDocument>) { }

    async createEntity(data: UpdateAboutPageComponentUIDto): Promise<AboutPageComponentUIDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<AboutPageComponentUIDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateAboutPageComponentUIDto): Promise<AboutPageComponentUIDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<AboutPageComponentUIDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<AboutPageComponentUIDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<AboutPageComponentUIDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}