import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { AboutPageComponentUIRepository } from "./about-page-component-ui.repository";
import { AboutPageComponentUI } from "./schema/about-page-component-ui.schema";
import { UpdateAboutPageComponentUIDto } from "./dto/update-about-page-component-ui.dto";


@Injectable()
export class AboutPageComponentUIService {
    constructor(
        @InjectModel('about_page_component_ui')
        private readonly aboutPageComponentUIModel: Model<AboutPageComponentUI>
    ) { }

    private readonly aboutPageComponentUIRepository = new AboutPageComponentUIRepository(this.aboutPageComponentUIModel);

    async updateOrCreateData(dto: UpdateAboutPageComponentUIDto): Promise<AboutPageComponentUI | Error> {
        const isExists = await this.aboutPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.aboutPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.aboutPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AboutPageComponentUI[] | Error> {
        const data = await this.aboutPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}