import mongoose, { Model, Types } from 'mongoose';
import { UpdateBlogDetailsPageComponentUIDto } from './dto/update-blog-details-page-component-ui.dto';
import { BlogDetailsPageComponentUI } from './schema/blog-details-page-component-ui.schema';

export class BlogDetailsPageComponentUIRepository<BlogDetailsPageComponentUIDocument extends BlogDetailsPageComponentUI> {
    constructor(private readonly model: Model<BlogDetailsPageComponentUIDocument>) { }

    async createEntity(data: UpdateBlogDetailsPageComponentUIDto): Promise<BlogDetailsPageComponentUIDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<BlogDetailsPageComponentUIDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateBlogDetailsPageComponentUIDto): Promise<BlogDetailsPageComponentUIDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<BlogDetailsPageComponentUIDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<BlogDetailsPageComponentUIDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<BlogDetailsPageComponentUIDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}