import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { BlogDetailsPageComponentUIRepository } from "./blog-details-page-component-ui.repository";
import { UpdateBlogDetailsPageComponentUIDto } from "./dto/update-blog-details-page-component-ui.dto";
import { BlogDetailsPageComponentUI } from "./schema/blog-details-page-component-ui.schema";

@Injectable()
export class BlogDetailsPageComponentUIService {
    constructor(
        @InjectModel('blog_details_page_component_ui')
        private readonly blogDetailsPageComponentUIModel: Model<BlogDetailsPageComponentUI>
    ) { }

    private readonly blogDetailsPageComponentUIRepository = new BlogDetailsPageComponentUIRepository(this.blogDetailsPageComponentUIModel);

    async updateOrCreateData(dto: UpdateBlogDetailsPageComponentUIDto): Promise<BlogDetailsPageComponentUI | Error> {
        const isExists = await this.blogDetailsPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.blogDetailsPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.blogDetailsPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<BlogDetailsPageComponentUI[] | Error> {
        const data = await this.blogDetailsPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}