import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { BlogPageComponentUIRepository } from "./blog-page-component-ui.repository";
import { UpdateBlogPageComponentUIDto } from "./dto/update-blog-page-component-ui.dto";
import { BlogPageComponentUI } from "./schema/blog-page-component-ui.schema";

@Injectable()
export class BlogPageComponentUIService {
    constructor(
        @InjectModel('blog_page_component_ui')
        private readonly blogPageComponentUIModel: Model<BlogPageComponentUI>
    ) { }

    private readonly blogPageComponentUIRepository = new BlogPageComponentUIRepository(this.blogPageComponentUIModel);

    async updateOrCreateData(dto: UpdateBlogPageComponentUIDto): Promise<BlogPageComponentUI | Error> {
        const isExists = await this.blogPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.blogPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.blogPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<BlogPageComponentUI[] | Error> {
        const data = await this.blogPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}