import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { MongooseModule } from "@nestjs/mongoose";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { UsersSchema } from "../../CRUD/users/schema/users.schema";
import { CommonComponentUIController } from "./common-component-ui.controller";
import { CommonComponentUIService } from "./common-component-ui.service";
import { CommonComponentUISchema } from "./schema/common-component-ui.schema";

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MongooseModule.forFeature([
            { name: 'users', schema: UsersSchema },
            { name: 'common_component_ui', schema: CommonComponentUISchema },
        ]),
    ],
    controllers: [CommonComponentUIController],
    providers: [CommonComponentUIService, JwtHelper]
})

export class CommonComponentUIModule { }
