import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CommonComponentUIRepository } from "./common-component-ui.repository";
import { UpdateCommonComponentUIDto } from "./dto/update-common-component-ui.dto";
import { CommonComponentUI } from "./schema/common-component-ui.schema";

@Injectable()
export class CommonComponentUIService {
    constructor(
        @InjectModel('common_component_ui')
        private readonly commonComponentUIModel: Model<CommonComponentUI>
    ) { }

    private readonly commonComponentUIRepository = new CommonComponentUIRepository(this.commonComponentUIModel);

    async updateOrCreateData(dto: UpdateCommonComponentUIDto): Promise<CommonComponentUI | Error> {
        const isExists = await this.commonComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.commonComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.commonComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CommonComponentUI[] | Error> {
        const data = await this.commonComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}