import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { ContactPageComponentUIRepository } from "./contact-page-component-ui.repository";
import { UpdateContactPageComponentUIDto } from "./dto/update-contact-page-component-ui.dto";
import { ContactPageComponentUI } from "./schema/contact-page-component-ui.schema";

@Injectable()
export class ContactPageComponentUIService {
    constructor(
        @InjectModel('contact_page_component_ui')
        private readonly contactPageComponentUIModel: Model<ContactPageComponentUI>
    ) { }

    private readonly contactPageComponentUIRepository = new ContactPageComponentUIRepository(this.contactPageComponentUIModel);

    async updateOrCreateData(dto: UpdateContactPageComponentUIDto): Promise<ContactPageComponentUI | Error> {
        const isExists = await this.contactPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.contactPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.contactPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ContactPageComponentUI[] | Error> {
        const data = await this.contactPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}