import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateFaqPageComponentUIDto } from "./dto/update-faq-page-component-ui.dto";
import { FaqPageComponentUIRepository } from "./faq-page-component-ui.repository";
import { FaqPageComponentUI } from "./schema/faq-page-component-ui.schema";

@Injectable()
export class FaqPageComponentUIService {
    constructor(
        @InjectModel('faq_page_component_ui')
        private readonly faqPageComponentUIModel: Model<FaqPageComponentUI>
    ) { }

    private readonly faqPageComponentUIRepository = new FaqPageComponentUIRepository(this.faqPageComponentUIModel);

    async updateOrCreateData(dto: UpdateFaqPageComponentUIDto): Promise<FaqPageComponentUI | Error> {
        const isExists = await this.faqPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.faqPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.faqPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<FaqPageComponentUI[] | Error> {
        const data = await this.faqPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}