import mongoose, { Model, Types } from 'mongoose';
import { UpdateHomePageComponentUIDto } from './dto/update-home-page-component-ui.dto';
import { HomePageComponentUI } from './schema/home-page-component-ui.schema';

export class HomePageComponentUIRepository<HomePageComponentUIDocument extends HomePageComponentUI> {
    constructor(private readonly model: Model<HomePageComponentUIDocument>) { }

    async createEntity(data: UpdateHomePageComponentUIDto): Promise<HomePageComponentUIDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomePageComponentUIDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomePageComponentUIDto): Promise<HomePageComponentUIDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<HomePageComponentUIDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomePageComponentUIDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<HomePageComponentUIDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}