import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateHomePageComponentUIDto } from "./dto/update-home-page-component-ui.dto";
import { HomePageComponentUIRepository } from "./home-page-component-ui.repository";
import { HomePageComponentUI } from "./schema/home-page-component-ui.schema";

@Injectable()
export class HomePageComponentUIService {
    constructor(
        @InjectModel('home_page_component_ui')
        private readonly homePageComponentUIModel: Model<HomePageComponentUI>
    ) { }

    private readonly homePageComponentUIRepository = new HomePageComponentUIRepository(this.homePageComponentUIModel);

    async updateOrCreateData(dto: UpdateHomePageComponentUIDto): Promise<HomePageComponentUI | Error> {
        const isExists = await this.homePageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.homePageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.homePageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageComponentUI[] | Error> {
        const data = await this.homePageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}