import mongoose, { Model, Types } from 'mongoose';
import { LegalPageComponentUI } from './schema/legal-page-component-ui.schema';
import { UpdateLegalPageComponentUIDto } from './dto/update-legal-page-component-ui.dto';


export class LegalPageComponentUIRepository<LegalPageComponentUIDocument extends LegalPageComponentUI> {
    constructor(private readonly model: Model<LegalPageComponentUIDocument>) { }

    async createEntity(data: UpdateLegalPageComponentUIDto): Promise<LegalPageComponentUIDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<LegalPageComponentUIDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateLegalPageComponentUIDto): Promise<LegalPageComponentUIDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<LegalPageComponentUIDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<LegalPageComponentUIDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<LegalPageComponentUIDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}