import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { LegalPageComponentUI } from "./schema/legal-page-component-ui.schema";
import { LegalPageComponentUIRepository } from "./legal-page-component-ui.repository";
import { UpdateLegalPageComponentUIDto } from "./dto/update-legal-page-component-ui.dto";


@Injectable()
export class LegalPageComponentUIService {
    constructor(
        @InjectModel('legal_page_component_ui')
        private readonly legalPageComponentUIModel: Model<LegalPageComponentUI>
    ) { }

    private readonly legalPageComponentUIRepository = new LegalPageComponentUIRepository(this.legalPageComponentUIModel);

    async updateOrCreateData(dto: UpdateLegalPageComponentUIDto): Promise<LegalPageComponentUI | Error> {
        const isExists = await this.legalPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.legalPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.legalPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<LegalPageComponentUI[] | Error> {
        const data = await this.legalPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}