import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdatePrivacyPolicyPageComponentUIDto } from "./dto/update-privacy-policy-page-component-ui.dto";
import { PrivacyPolicyPageComponentUIRepository } from "./privacy-policy-page-component-ui.repository";
import { PrivacyPolicyPageComponentUI } from "./schema/privacy-policy-page-component-ui.schema";

@Injectable()
export class PrivacyPolicyPageComponentUIService {
    constructor(
        @InjectModel('privacy_policy_page_component_ui')
        private readonly privacyPolicyPageComponentUIModel: Model<PrivacyPolicyPageComponentUI>
    ) { }

    private readonly privacyPolicyPageComponentUIRepository = new PrivacyPolicyPageComponentUIRepository(this.privacyPolicyPageComponentUIModel);

    async updateOrCreateData(dto: UpdatePrivacyPolicyPageComponentUIDto): Promise<PrivacyPolicyPageComponentUI | Error> {
        const isExists = await this.privacyPolicyPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.privacyPolicyPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.privacyPolicyPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PrivacyPolicyPageComponentUI[] | Error> {
        const data = await this.privacyPolicyPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}