import mongoose, { Model, Types } from 'mongoose';
import { TermsAndConditionPageComponentUI } from './schema/terms-and-condition-page-component-ui.schema';
import { UpdateTermsAndConditionPageComponentUIDto } from './dto/update-terms-and-condition-page-component-ui.dto';


export class TermsAndConditionPageComponentUIRepository<TermsAndConditionPageComponentUIDocument extends TermsAndConditionPageComponentUI> {
    constructor(private readonly model: Model<TermsAndConditionPageComponentUIDocument>) { }

    async createEntity(data: UpdateTermsAndConditionPageComponentUIDto): Promise<TermsAndConditionPageComponentUIDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<TermsAndConditionPageComponentUIDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateTermsAndConditionPageComponentUIDto): Promise<TermsAndConditionPageComponentUIDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<TermsAndConditionPageComponentUIDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<TermsAndConditionPageComponentUIDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<TermsAndConditionPageComponentUIDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}