import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { TermsAndConditionPageComponentUI } from "./schema/terms-and-condition-page-component-ui.schema";
import { TermsAndConditionPageComponentUIRepository } from "./terms-and-condition-page-component-ui.repository";
import { UpdateTermsAndConditionPageComponentUIDto } from "./dto/update-terms-and-condition-page-component-ui.dto";


@Injectable()
export class TermsAndConditionPageComponentUIService {
    constructor(
        @InjectModel('terms_and_condition_page_component_ui')
        private readonly termsAndConditionPageComponentUIModel: Model<TermsAndConditionPageComponentUI>
    ) { }

    private readonly termsAndConditionPageComponentUIRepository = new TermsAndConditionPageComponentUIRepository(this.termsAndConditionPageComponentUIModel);

    async updateOrCreateData(dto: UpdateTermsAndConditionPageComponentUIDto): Promise<TermsAndConditionPageComponentUI | Error> {
        const isExists = await this.termsAndConditionPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.termsAndConditionPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.termsAndConditionPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<TermsAndConditionPageComponentUI[] | Error> {
        const data = await this.termsAndConditionPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}