import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { TypesOfInjuriesPageComponentUI } from "./schema/types-of-injuries-page-component-ui.schema";
import { TypesOfInjuriesPageComponentUIRepository } from "./types-of-injuries-page-component-ui.repository";
import { UpdateTypesOfInjuriesPageComponentUIDto } from "./dto/update-types-of-injuries-page-component-ui.dto";



@Injectable()
export class TypesOfInjuriesPageComponentUIService {
    constructor(
        @InjectModel('types_of_injuries_page_component_ui')
        private readonly typesOfInjuriesPPageComponentUIModel: Model<TypesOfInjuriesPageComponentUI>
    ) { }

    private readonly typesOfInjuriesPageComponentUIRepository = new TypesOfInjuriesPageComponentUIRepository(this.typesOfInjuriesPPageComponentUIModel);

    async updateOrCreateData(dto: UpdateTypesOfInjuriesPageComponentUIDto): Promise<TypesOfInjuriesPageComponentUI | Error> {
        const isExists = await this.typesOfInjuriesPageComponentUIRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.typesOfInjuriesPageComponentUIRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.typesOfInjuriesPageComponentUIRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<TypesOfInjuriesPageComponentUI[] | Error> {
        const data = await this.typesOfInjuriesPageComponentUIRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}