import { Module } from '@nestjs/common';
import { JwtModule } from '@nestjs/jwt';
import JwtConfigService from 'src/core/jwt/jwt-config.service';
import JwtHelper from 'src/core/jwt/jwt.helper';
import { AuthController } from './auth.controller';
import { AuthService } from './auth.service';
import { MongooseModule } from '@nestjs/mongoose';
import { UsersSchema } from '../CRUD/users/schema/users.schema';
import { ChangePasswordTokenSchema } from '../CRUD/change-password-token/schema/change-password-token.schema';
import { MailSenderService } from '../mail-sender/mail-sender.service';

@Module({
    imports: [
        MongooseModule.forFeature([
            { name: 'Users', schema: UsersSchema },
            { name: "change_password_token", schema: ChangePasswordTokenSchema }
        ]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        })
    ],
    controllers: [AuthController],
    providers: [AuthService, JwtHelper, MailSenderService]
})
export class AuthModule {}
