import { Module } from '@nestjs/common';
import { JwtModule } from '@nestjs/jwt';
import { MongooseModule } from '@nestjs/mongoose';

import JwtConfigService from 'src/core/jwt/jwt-config.service';
import JwtHelper from 'src/core/jwt/jwt.helper';

import { UsersSchema } from '../CRUD/users/schema/users.schema';
import { SiteFrontendController } from './site-frontend.controller';
import { SiteFrontendService } from './site-frontend.service';
import { HomePageHeroCmsSchema } from '../CMS/home-page-hero-section/schema/home-page-hero-cms.schema';
import { HomePageSectionTwoCmsSchema } from '../CMS/home-page-section-two-cms/schema/home-page-section-two-cms.schema';
import { VideoTestimonialCmsSchema } from '../CMS/video-testimonial-cms/schema/video-testimonial-cms.schema';
import { CommonVideoSectionCmsSchema } from '../CMS/common-video-section-cms/schema/common-video-section-cms.schema';
import { CtaOneSectionCmsSchema } from '../CMS/cta-one-section-cms/schema/cta-one-section-cms.schema';
import { CtaThreeSectionCmsSchema } from '../CMS/cta-three-section-cms/schema/cta-three-section-cms.schema';
import { CtaTwoSectionCmsSchema } from '../CMS/cta-two-section-cms/schema/cta-two-section-cms.schema';
import { CategorySectionCmsSchema } from '../CMS/category-section-cms/schema/category-section-cms.schema';
import { CommonFormCmsSchema } from '../CMS/common-form-cms/schema/common-form-cms.schema';
import { CommonFormSectionCmsSchema } from '../CMS/common-form-section-cms/schema/common-form-section-cms.schema';
import { VideoTestimonialSchema } from '../CRUD/video-testimonial/schema/video-testimonial.schema';
import { SubmitFormSuccessCmsSchema } from '../CMS/submit-form-success-cms/schema/submit-form-success-cms.schema';
import { NewsletterSectionCmsSchema } from '../CMS/newsletter-section-cms/schema/newsletter-section-cms.schema';
import { AttentionAlertCmsSchema } from '../CMS/attention-alert-cms/schema/attention-alert-cms.schema';
import { FaqSectionCmsSchema } from '../CMS/faq-section-cms/schema/faq-section-cms.schema';
import { FaqSchema } from '../CRUD/faq/schema/faq.schema';
import { TestimonialSectionCmsSchema } from '../CMS/testimonial-section-cms/schema/testimonial-section-cms.schema';
import { BlogSectionCmsSchema } from '../CMS/blog-section-cms/schema/blog-section-cms.schema';
import { HeaderFooterCmsSchema } from '../CMS/header-footer-cms/schema/header-footer-cms.schema';
import { AboutSectionOneCmsSchema } from '../CMS/about-section-one-cms/schema/about-section-one-cms.schema';
import { ContactPageCmsSchema } from '../CMS/contact-page-cms/schema/contact-page-cms.schema';
import { BlogSchema } from '../CRUD/blog/schema/blog.schema';
import { TermsConditionsPageCmsSchema } from '../CMS/terms-condition-page-cms/schema/terms-condition-page-cms.schema';
import { PrivacyPolicyPageCmsSchema } from '../CMS/privacy-policy-page-cms/schema/privacy-policy-page-cms-page-cms.schema';
import { LegalPageCmsSchema } from '../CMS/legal-page-cms/schema/legal-page-cms.schema';
import { SocialLinksSchema } from '../CRUD/social-links/schema/social-links.schema';
import { TestimonialSchema } from '../CRUD/testimonial/schema/testimonial.schema';
import { CategoryDetailsSchema } from '../CRUD/category-details/schema/category-details.schema';
import { PageTitleCmsSchema } from '../CMS/page-title-cms/schema/page-title-cms.schema';
import { PageBannerCmsSchema } from '../CMS/page-banner-cms/schema/page-banner-cms.schema';
import { HomePageComponentUISchema } from '../ComponentUICMS/home-page-component-ui/schema/home-page-component-ui.schema';
import { AboutPageComponentUISchema } from '../ComponentUICMS/about-page-component-ui/schema/about-page-component-ui.schema';
import { ContactSchema } from '../CRUD/contact/schema/contact.schema';
import { CommonFormSubmitSchema } from '../CRUD/common-form-submit/schema/common-form-submit.schema';
import { TermsAndConditionPageComponentUISchema } from '../ComponentUICMS/terms-and-condition-page-component-ui/schema/terms-and-condition-page-component-ui.schema';
import { ContactPageComponentUISchema } from '../ComponentUICMS/contact-page-component-ui/schema/contact-page-component-ui.schema';
import { BlogPageComponentUISchema } from '../ComponentUICMS/blog-page-component-ui/schema/blog-page-component-ui.schema';
import { BlogDetailsPageComponentUISchema } from '../ComponentUICMS/blog-details-page-component-ui/schema/blog-details-page-component-ui.schema';
import { PrivacyPolicyPageComponentUISchema } from '../ComponentUICMS/privacy-policy-page-component-ui/schema/privacy-policy-page-component-ui.schema';
import { LegalPageComponentUISchema } from '../ComponentUICMS/legal-page-component-ui/schema/legal-page-component-ui.schema';
import { TypesOfInjuriesPageComponentUISchema } from '../ComponentUICMS/types-of-injuries-page-component-ui/schema/types-of-injuries-page-component-ui.schema';
import { FaqPageComponentUISchema } from '../ComponentUICMS/faq-page-component-ui/schema/faq-page-component-ui.schema';
import { CommonComponentUISchema } from '../ComponentUICMS/common-component-ui/schema/common-component-ui.schema';
import { MetaDataCmsSchema } from '../CMS/meta-data-cms/schema/meta-data-cms.schema';

@Module({
  imports: [
    JwtModule.registerAsync({
      useClass: JwtConfigService,
    }),
    MongooseModule.forFeature([
      { name: 'users', schema: UsersSchema },
      { name: 'home_page_hero_cms', schema: HomePageHeroCmsSchema },
      {
        name: 'home_page_section_two_cms',
        schema: HomePageSectionTwoCmsSchema,
      },
      { name: 'video_testimonial_cms', schema: VideoTestimonialCmsSchema },
      { name: 'common_video_section_cms', schema: CommonVideoSectionCmsSchema },
      { name: 'cta-one-section-cms', schema: CtaOneSectionCmsSchema },
      { name: 'cta-two-section-cms', schema: CtaTwoSectionCmsSchema },
      { name: 'cta-three-section-cms', schema: CtaThreeSectionCmsSchema },
      { name: 'category_section_cms', schema: CategorySectionCmsSchema },
      { name: 'common_form_cms', schema: CommonFormCmsSchema },
      { name: 'common_form_section_cms', schema: CommonFormSectionCmsSchema },
      { name: 'video_testimonial', schema: VideoTestimonialSchema },
      { name: 'submit_form_success_cms', schema: SubmitFormSuccessCmsSchema },
      { name: 'newsletter_section_cms', schema: NewsletterSectionCmsSchema },
      { name: 'attention_alert_cms', schema: AttentionAlertCmsSchema },
      { name: 'faq_section_cms', schema: FaqSectionCmsSchema },
      { name: 'faq', schema: FaqSchema },
      { name: 'testimonial-section-cms', schema: TestimonialSectionCmsSchema },
      { name: 'testimonial', schema: TestimonialSchema },
      { name: 'blog-section-cms', schema: BlogSectionCmsSchema },
      { name: 'header_footer_cms', schema: HeaderFooterCmsSchema },
      { name: 'about_section_one_cms', schema: AboutSectionOneCmsSchema },
      { name: 'contact_page_cms', schema: ContactPageCmsSchema },
      { name: 'blog', schema: BlogSchema },
      { name: 'terms_condition_page_cms', schema: TermsConditionsPageCmsSchema },
      { name: 'privacy_policy_page_cms', schema: PrivacyPolicyPageCmsSchema },
      { name: 'legal_page_cms', schema: LegalPageCmsSchema },
      { name: 'social-links', schema: SocialLinksSchema },
      { name: 'category_details', schema: CategoryDetailsSchema },
      { name: 'page_title_cms', schema: PageTitleCmsSchema },
      { name: 'page_banner_cms', schema: PageBannerCmsSchema },
      { name: 'meta_data_cms', schema: MetaDataCmsSchema },
      { name: 'home_page_component_ui', schema: HomePageComponentUISchema },
      { name: 'about_page_component_ui', schema: AboutPageComponentUISchema },
      { name: 'contact', schema: ContactSchema },
      { name: 'common-form-submit', schema: CommonFormSubmitSchema },
      { name: 'terms_and_condition_page_component_ui', schema: TermsAndConditionPageComponentUISchema },
      { name: 'contact_page_component_ui', schema: ContactPageComponentUISchema },
      { name: 'blog_page_component_ui', schema: BlogPageComponentUISchema },
      { name: 'blog_details_page_component_ui', schema: BlogDetailsPageComponentUISchema },
      { name: 'privacy_policy_page_component_ui', schema: PrivacyPolicyPageComponentUISchema },
      { name: 'legal_page_component_ui', schema: LegalPageComponentUISchema },
      { name: 'types_of_injuries_page_component_ui', schema: TypesOfInjuriesPageComponentUISchema },
      { name: 'faq_page_component_ui', schema: FaqPageComponentUISchema },
      { name: 'common_component_ui', schema: CommonComponentUISchema },
      
    ]),
  ],
  controllers: [SiteFrontendController],
  providers: [SiteFrontendService, JwtHelper],
})
export class SiteFrontendModule {}
